@@ -251,15 +251,19 @@ impl<'a, W> fmt::Write for CssStringWriter<'a, W> where W: fmt::Write {
         let mut chunk_start = 0;
         for (i, b) in s.bytes().enumerate() {
             let escaped = match b {
-                b'"' => "\\\"",
-                b'\\' => "\\\\",
-                b'\n' => "\\A ",
-                b'\r' => "\\D ",
-                b'\x0C' => "\\C ",
+                b'"' => Some("\\\""),
+                b'\\' => Some("\\\\"),
+                b'\n' => Some("\\A "),
+                b'\r' => Some("\\D "),
+                b'\0' => Some("\u{FFFD}"),
+                b'\x01'...b'\x1F' | b'\x7F' => None,
                 _ => continue,
             };
             try!(self.inner.write_str(&s[chunk_start..i]));
-            try!(self.inner.write_str(escaped));
+            match escaped {
+                Some(x) => try!(self.inner.write_str(x)),
+                None => try!(write!(self.inner, "\\{:x} ", b)),
+            };
             chunk_start = i + 1;
         }
         self.inner.write_str(&s[chunk_start..])
